@@ -1,6 +1,6 @@
 
 
-### Copyright 2001-2004  Deepayan Sarkar <deepayan@stat.wisc.edu>
+### Copyright (C) 2001-2005  Deepayan Sarkar <Deepayan.Sarkar@R-project.org>
 ###
 ### This file is part of the lattice library for R.
 ### It is made available under the terms of the GNU General Public
@@ -176,9 +176,25 @@ panel.parallel <-
 
 
 
+parallel <- function(formula, ...)  UseMethod("parallel")
 
 
-parallel <-
+parallel.data.frame <-
+    function(formula, data = NULL, ...)
+{
+    ocall <- ccall <- match.call()
+    if (!is.null(ccall$data)) 
+        warning("explicit data specification ignored")
+    ccall$data <- list(x = formula)
+    ccall$formula <- ~x
+    ccall[[1]] <- as.name("parallel")
+    ans <- eval(ccall, parent.frame())
+    ans$call <- ocall
+    ans
+}
+
+
+parallel.formula <-
     function(formula,
              data = parent.frame(),
              aspect = "fill",
@@ -212,35 +228,35 @@ parallel <-
     ## Step 1: Evaluate x, y, etc. and do some preprocessing
     
     right.name <- deparse(substitute(formula))
-    formula <- eval(substitute(formula), data, parent.frame())
+    ## formula <- eval(substitute(formula), data, parent.frame())
     form <-
-        if (inherits(formula, "formula"))
-            latticeParseFormula(formula, data,
-                                subset = subset, groups = groups,
-                                multiple = FALSE,
-                                outer = FALSE, subscripts = TRUE,
-                                drop = drop.unused.levels)
-        else {
-            if (is.matrix(formula)) {
-                list(left = NULL,
-                     right = as.data.frame(formula)[subset,],
-                     condition = NULL,
-                     left.name = "",
-                     right.name =  right.name,
-                     groups = groups,
-                     subscr = seq(length = nrow(formula))[subset])
-            }
-            else if (is.data.frame(formula)) {
-                list(left = NULL,
-                     right = formula[subset,],
-                     condition = NULL,
-                     left.name = "",
-                     right.name =  right.name,
-                     groups = groups,
-                     subscr = seq(length = nrow(formula))[subset])
-            }
-            else stop("invalid formula")
-        }
+        ## if (inherits(formula, "formula"))
+        latticeParseFormula(formula, data,
+                            subset = subset, groups = groups,
+                            multiple = FALSE,
+                            outer = FALSE, subscripts = TRUE,
+                            drop = drop.unused.levels)
+##         else {
+##             if (is.matrix(formula)) {
+##                 list(left = NULL,
+##                      right = as.data.frame(formula)[subset,],
+##                      condition = NULL,
+##                      left.name = "",
+##                      right.name =  right.name,
+##                      groups = groups,
+##                      subscr = seq(length = nrow(formula))[subset])
+##             }
+##             else if (is.data.frame(formula)) {
+##                 list(left = NULL,
+##                      right = formula[subset,],
+##                      condition = NULL,
+##                      left.name = "",
+##                      right.name =  right.name,
+##                      groups = groups,
+##                      subscr = seq(length = nrow(formula))[subset])
+##             }
+##             else stop("invalid formula")
+##         }
 
 
     ## We need to be careful with subscripts here. It HAS to be there,
